<?xml version="1.0"?>
<!DOCTYPE book PUBLIC "-//OASIS//DTD DocBook XML V4.5//EN"
                    "http://www.oasis-open.org/docbook/xml/4.5/docbookx.dtd"
[
<!ENTITY % MATHML.prefixed "INCLUDE">
<!ENTITY % MATHML.prefix "mml">
<!ENTITY % equation.content "(alt?, (graphic+|mediaobject+|mml:math))">
<!ENTITY % inlineequation.content
                "(alt?, (inlinegraphic+|inlinemediaobject+|mml:math))">
<!ENTITY % mathml PUBLIC "-//W3C//DTD MathML 2.0//EN"
        "http://www.w3.org/Math/DTD/mathml2/mathml2.dtd">
]>

<article xmlns="http://docbook.org/ns/docbook"
         xmlns:mml="http://www.w3.org/1998/Math/MathML"
 id="manual">
  <articleinfo>
    <title>maxlink</title>
  </articleinfo>
  <sect1 id="introduction">
    <title>Introduction</title>
    <para>
Maxlink is a software that implements the network searching algorithm that was first described in the article "Network-based Identification of Novel Cancer Genes" <ulink url="http://sonnhammer.sbc.su.se/download/papers/2010_MCP_9:648-655.pdf">PDF</ulink> <biblioref linkend="Östlund:2010"/>. 

This software is open source software. It is written in the programming language C++ and it is licensed under the <ulink url="http://www.boost.org/LICENSE_1_0.txt">Boost Software license version 1.0.</ulink></para>
  </sect1>

  <sect1 id="maxlink_algorithms">
    <title>Maxlink algorithms</title>


  <sect2 id="maxlink_algorithm_version_1">
    <title>Maxlink algorithm version 1</title>
    <para>


  resultmethod can be either "ratio" or "hypergeometric"

<programlisting><![CDATA[
G(V,E)

V={v1, v2, v3, ..., vn}
E={e1, e2, e3, ..., em}

list of query genes C={c1, c2, c3, ..., ck}
list of unknow genes U={u1, u2, u3, ..., uj}

C and U are disjoint sets.

C intersect U = empty set
C union U = V

E1 = { e = {vc1, vc2} | vc1 or vc2 member of C }
E2 = E difference E1 

The algorithm returns a subset of U:
--------------------------
Vresult = empty set

For each v member of U
  E3 = { e = {vc, v} | vc member of C }
  E4 = { e = {vu, v} | vu member of U }
  if resultmethod == ratio
    criteria = |E3| / |E4|
    if criteria > |E1| / |E2| then:
    Vresult = Vresult union {v}
  if resultmethod == hypergeometric
    k = |E3|
    t = |E3| + |E4|
    n1 = |E1|
    n2 = |E2|
    p = gsl_ran_hypergeometric_pdf(k, n1, n2, t) + gsl_cdf_hypergeometric_Q(k, n1, n2, t);
    where gsl_ran_hypergeometric_pdf gives the probability of obtaining k from 
    a hypergeometric distribution and gsl_cdf_hypergeometric_Q gives the probability of obtaining more than k
    from the hypergeometric distribution.
    For more info see:
    http://www.gnu.org/software/gsl/manual/html_node/The-Hypergeometric-Distribution.html
    if p < probability_cutoff
      Vresult = Vresult union {f}
]]></programlisting>

<!-- It would be nice to use MathML to write the equations
<inlineequation>
  <mml:math>
<mml:mrow>
 <mml:apply>
    <mml:intersect/>
    <mml:ci>&sigma;</mml:ci>
    <mml:ci>B</mml:ci>
  </mml:apply>

  <mml:ci type="set">Caaaaa</mml:ci>
 <mml:mo style="font-size: larger;">&cup;</mml:mo>
  <mml:ci type="set">N</mml:ci>

 <mml:mo>=</mml:mo>
 <mml:msub>
   <mml:mi>p</mml:mi>
   <mml:mn>trans</mml:mn>
 </mml:msub>

 <mml:apply>
    <mml:neq/>
    <mml:integers/>
    <mml:emptyset/>
  </mml:apply>
  


 <mml:msup>
   <mml:mi>e</mml:mi>
   <mml:mfrac><mml:mrow><mml:mi>ln</mml:mi><mml:mn>0.5</mml:mn></mml:mrow><mml:mi>L</mml:mi></mml:mfrac>
 </mml:msup>
</mml:mrow>
  </mml:math>
  

</inlineequation>

<inlineequation>
   <mml:math> 
      <mml:apply> 
        <mml:intersect/> 
        <mml:ci type="set"> A </mml:ci> 
        <mml:apply> 
          <mml:union/> 
          <mml:ci type="set"> B </mml:ci> 
          <mml:ci type="set"> C </mml:ci> 
        </mml:apply> 
      </mml:apply> 
    </mml:math>
</inlineequation>

next exquation

<equation>
  <mml:math>
    <mml:mstyle displaystyle="true">
    <mml:mrow>
      <mml:msubsup>
        <mml:mi>e</mml:mi>
        <mml:mi>q</mml:mi>
        <mml:mi>msa</mml:mi>
      </mml:msubsup>
      <mml:mo  stretchy="false">(</mml:mo>
      <mml:msubsup>
        <mml:mi>x</mml:mi>
        <mml:mi>k</mml:mi>
        <mml:mi>msa</mml:mi>
      </mml:msubsup>
      <mml:mo  stretchy="false">)</mml:mo>
      <mml:mo>=</mml:mo>
      <mml:munder>
        <mml:mrow>
          <mml:mo>
&sum;    </mml:mo>
        </mml:mrow>
        <mml:mi>j</mml:mi>
      </mml:munder>
      <mml:msub>
        <mml:mi>e</mml:mi>
        <mml:mi>q</mml:mi>
      </mml:msub>
      <mml:mo  stretchy="false">(</mml:mo>
      <mml:msub>
        <mml:mi>&sigma;</mml:mi>
        <mml:mi>j</mml:mi>
      </mml:msub>
      <mml:mo  stretchy="false">)</mml:mo>
      <mml:mo>*</mml:mo>
      <mml:msubsup>
        <mml:mi>x</mml:mi>
        <mml:mi>k</mml:mi>
        <mml:mi>msa</mml:mi>
      </mml:msubsup>
      <mml:mo  stretchy="false">(</mml:mo>
      <mml:msub>
        <mml:mi>&sigma;</mml:mi>
        <mml:mi>j</mml:mi>
      </mml:msub>
      <mml:mo  stretchy="false">)</mml:mo>
    </mml:mrow>
    </mml:mstyle>
  </mml:math>
</equation>

-->
</para>

</sect2>

<sect2 id="maxlink_algorithm_version_2">
  <title>Maxlink algorithm version 2</title>
    <para>
      <programlisting><![CDATA[
G(V,E)

V={v1, v2, v3, ..., vn}
E={e1, e2, e3, ..., em}

list of query genes C={c1, c2, c3, ..., ck}
list of unknow genes U={u1, u2, u3, ..., uj}

C and U are disjoint sets.

C intersect U = empty set
C union U = V

The algorithm returns a subset of U:
------------------------------------
Vresult = empty set
Vhash1 = empty hash
Vhash2 = empty hash

n1=0
For every unordered pair {x, y} where x and y are members of C but not equal,
  Find a shortest path s between x and y.
  If a shortest path exists 
    increment n1 with +1
    For every node m in the shortest path s
      if m is not a member of C and is not already a key in the hash Vhash1
        add m as a key to hash Vhash1 with the value 1
      else     
        increment value for key m in hash Vhash1 with +1

n2=0
For every unordered pair {x, y} where x and y are members of V but not equal,
  Find a shortest path s between x and y.
  If a shortest path exists 
    increment n2 with +1
    For every node m in the shortest path s
      if m is not already a key in the hash Vhash2
        add m as a key to hash Vhash with the value 1     
      else
        increment value for key m in hash Vhash2 with +1

Vresult = empty set
For every key f in hash Vhash1,
  k = Vhash1[f]
  t = Vhash2[f]
  p = gsl_ran_hypergeometric_pdf(k, n1, n2, t) + gsl_cdf_hypergeometric_Q(k, n1, n2, t);
    where gsl_ran_hypergeometric_pdf gives the probability of obtaining k from 
    a hypergeometric distribution and gsl_cdf_hypergeometric_Q gives the probability of obtaining more than k
    from the hypergeometric distribution.
    For more info see:
    http://www.gnu.org/software/gsl/manual/html_node/The-Hypergeometric-Distribution.html
  if p < probability_cutoff
    Vresult = Vresult union {f}
]]></programlisting>
</para>
</sect2>
</sect1>

  <sect1 id="download">
    <title>Download</title>
    <para>      
       Download the software from:
              <ulink url="http://maxlink.sbc.su.se/download/">http://maxlink.sbc.su.se/download/</ulink>
</para><para> 

 The latest version of maxlink is @PACKAGE_VERSION@. 
    </para>
  </sect1>

  <sect1 id="installation">
    <title>Installation</title>
    <sect2 id="installation_with_prebuilt_package">
      <title>Installation with prebuilt package</title>


<!--
    <sect3 id="installation_on_windows">
      <title>Installation on Windows with .exe file</title>
<para>
To install maxlink on Windows, first download the maxlink-@PACKAGE_VERSION@-win32.exe and then execute the file ( click on it ). 
    </para>
  </sect3>
-->


    <sect3 id="installation_on_ubuntu_and_debian">
      <title>Installation on Ubuntu and Debian</title>

<para>
To install maxlink on Ubuntu or Debian, first download the maxlink-@PACKAGE_VERSION@.deb  and then log in as root and  
<programlisting><![CDATA[
# dpkg -i maxlink-@PACKAGE_VERSION@.deb 
]]></programlisting>

    </para>
  </sect3>

<!--
    <sect3 id="installation_on_centos_and_fedora_linux">
      <title>Installation on CentOS and Fedora</title>

<para>
To install maxlink on Centos or Debian, first download the maxlink-@PACKAGE_VERSION@.Linux.rpm   and then log in as root and  
<programlisting><![CDATA[
# yum localinstall maxlink-@PACKAGE_VERSION@.Linux.rpm 
]]></programlisting>

    </para>
  </sect3> 



    <sect3 id="installation_MacOS_X">
      <title>Installation on Mac OS X</title>

<para>
To install maxlink on a Mac OS X v10.5 ( Leopard ) on a Mac computer with Intel cpu, first download the maxlink-@PACKAGE_VERSION@-MacOSX10.5.tar.gz   and then 
<programlisting><![CDATA[
$ tar xfz maxlink-@PACKAGE_VERSION@-MacOSX10.5.tar.gz  
]]></programlisting>

    </para>
<para>
To install maxlink on a Mac OS X v10.4 ( Tiger ) on a Mac computer with Intel cpu, first download the maxlink-@PACKAGE_VERSION@-MacOSX10.4.tar.gz   and then 
<programlisting><![CDATA[
$ tar xfz maxlink-@PACKAGE_VERSION@-MacOSX10.4.tar.gz
]]></programlisting>

    </para>
  </sect3>

-->
 </sect2>

    <sect2 id="building_from_source">
      <title>Building from source</title>

    <sect3 id="building_from_source_on_unix">
      <title>Building from source on Unix</title>

      <para>To build maxlink on Unix ( e.g. Linux, MacOSX, CygWin ) you need to have this installed
        <itemizedlist mark="bullet">
          <listitem>
            <para>
              <ulink url="http://www.cmake.org">cmake</ulink>
            </para>
          </listitem>
          <listitem>
            <para>
              <ulink url="http://fallabs.com/tokyocabinet/">Tokyo Cabinet</ulink>
            </para>
          </listitem>
          <listitem>
            <para>
              <ulink url="http://www.codesynthesis.com/products/xsd/">CodeSynthesis XSD</ulink>
            </para>
          </listitem>
          <listitem>
            <para>
              <ulink url="http://www.gnu.org/software/gengetopt/gengetopt.html">gengetopt</ulink>
            </para>
          </listitem>
          <listitem>
            <para>
              <ulink url="http://www.boost.org/">boost</ulink>
            </para>
          </listitem>
        </itemizedlist>
      </para>
      <para>

If you have a Ubuntu Linux computer (Ubuntu 10.04 or later) you can install all build requirements by running
<programlisting><![CDATA[
[root@linux ~]# apt-get install gengetopt xsdcxx libtokyocabinet8 libtokyocabinet-dev libboost-math-dev rpm libboost-dev cmake
]]></programlisting>

If you don't have root permissions on your linux computer and you have built and installed the required libraries somewhere in your home directory you will 
have to use the command line option -DCMAKE_PREFIX_PATH when you run the <application>cmake</application> command. That is a semi colon separated list of directories that cmake will search in when it looks for the build requirements.

      </para>
      <para>

If you have the maxlink source code in the directory <filename>/tmp/maxlink-@PACKAGE_VERSION@</filename> and you want to install maxlink into the directory <filename>/tmp/install</filename>, and you have installed gengetopt in the non-default location <filename>~/gengetopt/inst/</filename>, then

first run <command>cmake</command> then <command>make</command> and then <command>make install</command> (the command output was removed for brevity)
<programlisting><![CDATA[
[user@linux ~]$ mkdir /tmp/build
[user@linux ~]$ cd /tmp/build
[user@linux ~]$ cmake -DCMAKE_INSTALL_PREFIX=/tmp/install -DCMAKE_PREFIX_PATH=~/gengetopt/inst/ /tmp/maxlink-@PACKAGE_VERSION@
[user@linux ~]$ make
[user@linux ~]$ make install
]]></programlisting>

If you want to build the html documentation ( i.e. this page ) you need to pass the -DBUILD_DOCUMENTATION=on option to <application>cmake</application>.
      </para>
      <para>
If you want to build a debian package and rpm package, you run: (the command output was removed for brevity)
<programlisting><![CDATA[
[user@linux ~]$ mkdir /tmp/build
[user@linux ~]$ cd /tmp/build
[user@linux ~]$ cmake -DCMAKE_INSTALL_PREFIX=/tmp/install -DCMAKE_PREFIX_PATH=~/gengetopt/inst/bin/ /tmp/maxlink-@PACKAGE_VERSION@
[user@linux ~]$ make
[user@linux ~]$ make package
]]></programlisting>

      </para>
    </sect3>
   </sect2>
  </sect1>
  <sect1 id="usage">
   <title>Usage</title>
    <sect2 id="maxlink-load">
    <title>maxlink-load</title>

  <sect3 id="maxlink-load_command_line_options">
    <title>maxlink-load command line options</title>
<para>

Type <userinput>maxlink-load --help</userinput> to see the command line options

<programlisting><repl shell-cmd="maxlink-load --help"/></programlisting>
</para></sect3>

  <sect3 id="maxlink-load_input_file_formats">
    <title>maxlink-load input file formats</title>
<para>
<table frame='all'><title>maxlink-load input file formats</title>
<tgroup cols='3' align='left' colsep='1' rowsep='1'>
<thead>
<row>
<entry>file format</entry>
<entry>short option</entry>
<entry>description</entry>
</row>
</thead>
<tbody>
<row>
<entry>Maxlink protein network TSV file format</entry>
<entry>-F tsv</entry>
<entry>See the section <xref linkend="maxlink_protein_network_tsv_format"/></entry>
</row>
<row>
<entry>Maxlink protein network XML file format</entry>
<entry>-F xml</entry>
<entry>See the section <xref linkend="maxlink_protein_network_xml_format"/></entry>
</row>
</tbody>
</tgroup>
</table>
</para>
  </sect3>
  <sect3 id="maxlink-load_examples">
  <title>maxlink-load examples</title>
  <para>
  <example id="load_edges1.xml_with_maxlink-load"><title>load edges1.xml with maxlink-load</title><para>
  We want to load the protein network described in the file <xref linkend="edges1.xml"/>.
<programlisting><repl shell-cmd="rm -rf /tmp/tcdir; mkdir /tmp/tcdir"/></programlisting>
<programlisting><repl shell-cmd="maxlink-load --tokyo-cabinet-dir=/tmp/tcdir --protein-network-file-format=xml --protein-network-filename=edges1.xml"/></programlisting>
</para>
</example>

<!--


<example id="maxlink_with_specified_gap_penalties"><title>maxlink with specified gap penalties</title><para>
This example is the same as <xref linkend="maxlink_with_query_in_fasta_format"/> but with gap penalties specified.
The penalty for starting an alignment gap was chosen to be -8 and the penalty for extending an alignment gap 
was chosen to be -1.


<programlisting><repl shell-cmd="maxlink -q query.fasta -d db.fasta -s blosum50.mat -i -8 -e -1"/></programlisting>

</para>
</example>

<example id="maxlink_with_query_in_profile_file_format"><title>maxlink with query in profile file format</title><para>
<note><para>Specifying query in profile format is not implemented yet. The function read_profile() needs to be written.</para></note>
We use the file described in <xref linkend="1R69.psi"/> as the query. 
We use the file described in <xref linkend="db.fasta"/> as database file and we use the file described in <xref linkend="blosum50.mat"/> as scoring matrix. 

<programlisting><repl shell-cmd="maxlink -p 1R69.psi -d db.fasta -s blosum50.mat"/></programlisting>

</para>
</example>

<example id="maxlink_with_benchmarking"><title>maxlink with benchmarking</title><para>

This example is the same as <xref linkend="maxlink_with_query_in_fasta_format"/> but with benchmarking. The computation speed 
Gigacells/second is printed.
<programlisting><repl shell-cmd="maxlink -q query.fasta -d db.fasta -s blosum50.mat -b"/></programlisting> 
Note, db.fasta is too small ( containing only 3 sequences ) to give a fair result for Gigacells/second. See also <xref linkend="performance_benchmarked_computation_speed"/>.
</para>
</example>
<example id="maxlink_with_verbose_benchmarking"><title>maxlink with verbose benchmarking</title><para>

This example is the same as <xref linkend="maxlink_with_query_in_fasta_format"/> but with verbose benchmarking. Benchmarking information is printed.
<programlisting><repl shell-cmd="maxlink -q query.fasta -d db.fasta -s blosum50.mat -B"/></programlisting> 
Note, db.fasta is too small ( containing only 3 sequences ) to give a fair result for Gigacells/second. See also <xref linkend="performance_benchmarked_computation_speed"/>.

</para>
</example>

-->
      </para>



    </sect3>
    </sect2>
    <sect2 id="maxlink-query1">
   <title>maxlink-query1</title>

<application>maxlink-query1</application> implements the Maxlink algorithm version 1 (see <xref linkend="maxlink_algorithm_version_1"/>). This program is run against a database directory created with <application>maxlink-load</application> (see <xref linkend="maxlink-load"/>).

  <sect3 id="maxlink-query1_command_line_options">
    <title>maxlink-query1 command line options</title>
<para>

Type <userinput>maxlink-query1 --help</userinput> to see the command line options

<programlisting><repl shell-cmd="maxlink-query1 --help"/></programlisting>
</para></sect3>



  <sect3 id="maxlink-query1_input_file_formats">
    <title>maxlink-query1 input file formats</title>
<para>
<table frame='all'><title>maxlink-query1 input file formats</title>
<tgroup cols='3' align='left' colsep='1' rowsep='1'>
<thead>
<row>
<entry>file format</entry>
<entry>short option</entry>
<entry>description</entry>
</row>
</thead>
<tbody>
<row>
<entry>Maxlink gene list text format</entry>
<entry>-N text</entry>
<entry>See the section <xref linkend="maxlink_gene_list_text_format"/></entry>
</row>
<row>
<entry>Maxlink gene list xml format</entry>
<entry>-N xml</entry>
<entry>See the section <xref linkend="maxlink_gene_list_xml_format"/></entry>
</row>
</tbody>
</tgroup>
</table>
</para>
  </sect3>

  <sect3 id="maxlink-query1_output_file_formats">
    <title>maxlink-query1 output file formats</title>
<para>
<table frame='all'><title>maxlink-query1 output file formats</title>
<tgroup cols='3' align='left' colsep='1' rowsep='1'>
<thead>
<row>
<entry>file format</entry>
<entry>short option</entry>
<entry>description</entry>
</row>
</thead>
<tbody>
<row>
<entry>Maxlink query1 output xml format</entry>
<entry>-f xml</entry>
<entry>See the section <xref linkend="maxlink_query1_result_xml_format"/></entry>
</row>
<row>
<entry>Maxlink query1 output tsv format</entry>
<entry>-f tsv</entry>
<entry>See the section <xref linkend="maxlink_query1_result_tsv_format"/></entry>
</row>
</tbody>
</tgroup>
</table>
</para>
  </sect3>


  <sect3 id="maxlink-query1_examples">
  <title>maxlink-query1 examples</title>
  <para>


  <example id="maxlink-query1_with_result_in_text_output"><title>maxlink-query1 with result in text output</title><para>
First load the database (see <xref linkend="load_edges1.xml_with_maxlink-load"/>).

As a list of query genes we use the gene list described in the file <xref linkend="genelist1.txt"/>.
 

<programlisting><repl shell-cmd="maxlink-query1 --tokyo-cabinet-dir=/tmp/tcdir --gene-list-file-format=text --gene-list-filename=genelist1.txt"/></programlisting>

</para>
</example>

  <example id="maxlink-query1_with_result_in_xml_output"><title>maxlink-query1 with result in xml output</title><para>
First load the database (see <xref linkend="load_edges1.xml_with_maxlink-load"/>).

As a list of query genes we use the gene list described in the file <xref linkend="genelist1.txt"/>.
 

<programlisting><repl shell-cmd="maxlink-query1 --tokyo-cabinet-dir=/tmp/tcdir --gene-list-file-format=text --gene-list-filename=genelist1.txt --output-format=xml"/></programlisting>

</para>
</example>



  <example id="maxlink-query1_with_result_in_xml_output"><title>maxlink-query1 with hypergeometric filter method and result in xml output</title><para>
First load the database (see <xref linkend="load_edges1.xml_with_maxlink-load"/>).

As a list of query genes we use the gene list described in the file <xref linkend="genelist1.txt"/>.
 

<programlisting><repl shell-cmd="maxlink-query1 --tokyo-cabinet-dir=/tmp/tcdir --gene-list-file-format=text --gene-list-filename=genelist1.txt --result-method hypergeometric   --probability-cutoff=0.99  --output-format=xml"/></programlisting>
Note, for this specific example we use --probability-cutoff=0.99, but a real scenario would be a low number closer to zero.
</para>
</example>


</para>
</sect3>



    </sect2>
    <sect2 id="maxlink-query2">
   <title>maxlink-query2</title>

<application>maxlink-query2</application> implements the Maxlink algorithm version 2 (see <xref linkend="maxlink_algorithm_version_2"/>). This program is run against a database directory created with <application>maxlink-load</application> (see <xref linkend="maxlink-load"/>).

  <sect3 id="maxlink-query2_command_line_options">
    <title>maxlink-query2 command line options</title>
<para>

Type <userinput>maxlink-query2 --help</userinput> to see the command line options

<programlisting><repl shell-cmd="maxlink-query2 --help"/></programlisting>
</para></sect3>



  <sect3 id="maxlink-query2_input_file_formats">
    <title>maxlink-query2 input file formats</title>
<para>
<table frame='all'><title>maxlink-query2 input file formats</title>
<tgroup cols='3' align='left' colsep='1' rowsep='1'>
<thead>
<row>
<entry>file format</entry>
<entry>short option</entry>
<entry>description</entry>
</row>
</thead>
<tbody>
<row>
<entry>Maxlink gene list text format</entry>
<entry>-N text</entry>
<entry>See the section <xref linkend="maxlink_gene_list_text_format"/></entry>
</row>
<row>
<entry>Maxlink gene list xml format</entry>
<entry>-N xml</entry>
<entry>See the section <xref linkend="maxlink_gene_list_xml_format"/></entry>
</row>
</tbody>
</tgroup>
</table>
</para>
  </sect3>

  <sect3 id="maxlink-query2_output_file_formats">
    <title>maxlink-query2 output file formats</title>
<para>
<table frame='all'><title>maxlink-query2 output file formats</title>
<tgroup cols='3' align='left' colsep='1' rowsep='1'>
<thead>
<row>
<entry>file format</entry>
<entry>short option</entry>
<entry>description</entry>
</row>
</thead>
<tbody>
<row>
<entry>Maxlink query2 output xml format</entry>
<entry>-f xml</entry>
<entry>See the section <xref linkend="maxlink_query2_result_xml_format"/></entry>
</row>
<row>
<entry>Maxlink gene list text format</entry>
<entry>-f tsv</entry>
<entry>See the section <xref linkend="maxlink_gene_list_text_format"/></entry>
</row>
</tbody>
</tgroup>
</table>
</para>
  </sect3>





  <sect3 id="maxlink-query2_examples">
  <title>maxlink-query2 examples</title>
  <para>


  <example id="maxlink-query2_with_result_in_text_output"><title>maxlink-query2 with result in text output</title><para>
First load the database (see <xref linkend="load_edges1.xml_with_maxlink-load"/>).

As a list of query genes we use the gene list described in the file <xref linkend="genelist1.txt"/>.
 
<programlisting><repl shell-cmd="maxlink-query2 --tokyo-cabinet-dir=/tmp/tcdir --gene-list-file-format=text --gene-list-filename=genelist1.txt  --probability-cutoff=0.8"/></programlisting>

Note, for this specific example we use --probability-cutoff=0.8, but a real scenario would be a low number closer to zero.

</para>
</example>

  <example id="maxlink-query2_with_result_in_xml_output"><title>maxlink-query2 with result in xml output</title><para>
First load the database (see <xref linkend="load_edges1.xml_with_maxlink-load"/>).

As a list of query genes we use the gene list described in the file <xref linkend="genelist1.txt"/>.
 

<programlisting><repl shell-cmd="maxlink-query2 --tokyo-cabinet-dir=/tmp/tcdir --gene-list-file-format=text --gene-list-filename=genelist1.txt --output-format=xml --probability-cutoff=0.8"/></programlisting>

</para>
</example>
  <example id="convert_maxlink_query2_result_xml_format_to_TSV"><title>convert maxlink query2 result xml format to TSV (tab separated values file)</title><para>
The command <application>xsltproc</application> is available on all Linux computers. To convert the file <xref linkend="maxlink_query2_result.xml"/> to TSV (tab separated values) you could run
<programlisting><repl shell-cmd="xsltproc  ../../xslt/convert_maxlink_query2_result_xml_format_to_TSV.xsl maxlink_query2_result.xml"/></programlisting>
</para>
</example>

</para>
</sect3>


    </sect2>
    </sect1>
  <sect1 id="file_formats">
    <title>File formats</title>
    <para>      
This software package handles the following file formats
</para>


  <sect2 id="maxlink_protein_network_xml_format">
    <title>Maxlink protein network xml format</title>
<para>

The Maxlink protein network xml format is specified by this XML Schema
<programlisting><xi:include xmlns:xi="http://www.w3.org/2001/XInclude" parse="text" encoding="UTF-8" href="@CMAKE_BINARY_DIR@/src/c++/maxlink.xsd">
<xi:fallback>
   couldn't xinclude file
</xi:fallback>
</xi:include></programlisting>

<example id="edges1.xml"><title>edges1.xml, an example file in the Maxlink protein network xml format</title><para>
The example file <ulink url="example_files/edges1.xml">edges1.xml</ulink> contains
<programlisting><xi:include xmlns:xi="http://www.w3.org/2001/XInclude" parse="text" encoding="UTF-8" href="@CMAKE_SOURCE_DIR@/src/docbook/example_files/edges1.xml">
<xi:fallback>
   couldn't xinclude file
</xi:fallback>
</xi:include></programlisting>
</para></example>



</para></sect2>

  <sect2 id="maxlink_protein_network_tsv_format">
    <title>Maxlink protein network tsv format</title>
<para>
<example id="edges1.tsv"><title>edges1.tsv, an example file in the Maxlink protein network tsv format</title><para>
The example file <ulink url="example_files/edges1.tsv">edges1.tsv</ulink> contains
<programlisting><xi:include xmlns:xi="http://www.w3.org/2001/XInclude" parse="text" encoding="UTF-8" href="@CMAKE_CURRENT_SOURCE_DIR@/src/docbook//example_files/edges1.tsv">
<xi:fallback>
   couldn't xinclude file
</xi:fallback>
</xi:include></programlisting>

The first line contains a header. The following lines have 4 columns. The first and second contain gene ids. The third column contains the FBS value specified as a float. The fourth column contains the PFC value specified as a float.

</para></example>
</para></sect2>




  <sect2 id="maxlink_gene_list_xml_format">
    <title>Maxlink gene list xml format</title>
<para>

The Maxlink gene list xml format is specified by this XML Schema
<programlisting><xi:include xmlns:xi="http://www.w3.org/2001/XInclude" parse="text" encoding="UTF-8" href="@CMAKE_BINARY_DIR@/src/c++/maxlink_gene_list.xsd">
<xi:fallback>
   couldn't xinclude file
</xi:fallback>
</xi:include></programlisting>

<example id="genelist1.xml"><title>genelist1.xml, an example file in the Maxlink gene list xml format</title><para>
The example file <ulink url="example_files/genelist1.xml">genelist1.xml</ulink> contains
<programlisting><xi:include xmlns:xi="http://www.w3.org/2001/XInclude" parse="text" encoding="UTF-8" href="@CMAKE_SOURCE_DIR@/src/docbook/example_files/genelist1.xml">
<xi:fallback>
   couldn't xinclude file
</xi:fallback>
</xi:include></programlisting>
</para></example>



</para></sect2>


  <sect2 id="maxlink_gene_list_text_format">
    <title>Maxlink gene list text format</title>
<para>

The Maxlink gene list text format contains list of gene ids separated by new lines.


<example id="genelist1.txt"><title>genelist1.txt, an example file in the Maxlink gene list text format</title><para>
The example file <ulink url="example_files/genelist1.txt">genelist1.txt</ulink> contains
<programlisting><xi:include xmlns:xi="http://www.w3.org/2001/XInclude" parse="text" encoding="UTF-8" href="@CMAKE_SOURCE_DIR@/src/docbook/example_files/genelist1.txt">
<xi:fallback>
   couldn't xinclude file
</xi:fallback>
</xi:include></programlisting>
</para></example>
</para></sect2>

  <sect2 id="maxlink_query1_result_tsv_format">
    <title>Maxlink query1 result tsv format</title>
<para>

The Maxlink query1 result tsv format is a tab separated table containing gene name, MaxLink score, p-value and ratio

<example id="maxlink_query1_result.tsv"><title>maxlink_query1_result.tsv, an example file in the Maxlink query1 result tsv format</title><para>
The example file <ulink url="example_files/maxlink_query1_result.tsv">maxlink_query1_result.tsv</ulink> contains
<programlisting><xi:include xmlns:xi="http://www.w3.org/2001/XInclude" parse="text" encoding="UTF-8" href="@CMAKE_SOURCE_DIR@/src/docbook/example_files/maxlink_query1_result.tsv">
<xi:fallback>
   couldn't xinclude file
</xi:fallback>
</xi:include></programlisting>
</para></example>
</para></sect2>

  <sect2 id="maxlink_query1_result_xml_format">
    <title>Maxlink query1 result xml format</title>
<para>

The Maxlink query1 result xml format is specified by this XML Schema
<programlisting><xi:include xmlns:xi="http://www.w3.org/2001/XInclude" parse="text" encoding="UTF-8" href="@CMAKE_BINARY_DIR@/src/c++/maxlink_query1_result.xsd">
<xi:fallback>
   couldn't xinclude file
</xi:fallback>
</xi:include></programlisting>

<example id="maxlink_query1_result.xml"><title>maxlink_query1_result.xml, an example file in the Maxlink query1 result xml format</title><para>
The example file <ulink url="example_files/maxlink_query1_result.xml">maxlink_query1_result.xml</ulink> contains
<programlisting><xi:include xmlns:xi="http://www.w3.org/2001/XInclude" parse="text" encoding="UTF-8" href="@CMAKE_SOURCE_DIR@/src/docbook/example_files/maxlink_query1_result.xml">
<xi:fallback>
   couldn't xinclude file
</xi:fallback>
</xi:include></programlisting>
</para></example>
</para></sect2>




  <sect2 id="maxlink_query2_result_xml_format">
    <title>Maxlink query2 result xml format</title>
<para>

The Maxlink query2 result xml format is specified by this XML Schema
<programlisting><xi:include xmlns:xi="http://www.w3.org/2001/XInclude" parse="text" encoding="UTF-8" href="@CMAKE_BINARY_DIR@/src/c++/maxlink_query2_result.xsd">
<xi:fallback>
   couldn't xinclude file
</xi:fallback>
</xi:include></programlisting>

<example id="maxlink_query2_result.xml"><title>maxlink_query2_result.xml, an example file in the Maxlink query2 result xml format</title><para>
The example file <ulink url="example_files/maxlink_query2_result.xml">maxlink_query2_result.xml</ulink> contains
<programlisting><xi:include xmlns:xi="http://www.w3.org/2001/XInclude" parse="text" encoding="UTF-8" href="@CMAKE_SOURCE_DIR@/src/docbook/example_files/maxlink_query2_result.xml">
<xi:fallback>
   couldn't xinclude file
</xi:fallback>
</xi:include></programlisting>
</para></example>
</para></sect2>


  </sect1>







  <sect1 id="performance_computation_speed">
    <title>Performance - computation speed</title>
    <para>
The implementation tries to compute as much in advance as possible, before any query has been issued. This means that <application>maxlink-load</application> is the time consuming part of Maxlink. Specially the computation of the shortest paths is time consuming. If you don't need to run  <application>maxlink-query2</application> (<xref linkend="maxlink-query2"/>) you can add the command line option --exclude-maxlink-version2 to <application>maxlink-load</application> to save time.


 </para>
  </sect1>

<!--
  <sect1 id="related_projects">
    <title>Related projects</title>
</sect1>
-->

<bibliography>
    <title>References</title>

<bibliomixed id="Östlund:2010">
  <bibliomset relation="article">
    <author><firstname>Gabriel</firstname> <surname>Östlund</surname></author>, <author><firstname>Mats</firstname> <surname>Lindskog</surname></author>, <author><firstname>Erik L. L.</firstname> <surname>Sonnhammer</surname></author>
    <title role="article">Network-based Identification of Novel Cancer Genes</title>.
  </bibliomset>
  <bibliomset relation="journal">
    <title>Molecular and Cellular Proteomics</title> 
   <volumenum>9</volumenum>(<issuenum>4</issuenum>):<pagenums>648-655</pagenums>, <pubdate>2010</pubdate></bibliomset>.
</bibliomixed>
    </bibliography>





</article>




