#ifndef STRING2NUM_GENE_DATABASE_H
#define STRING2NUM_GENE_DATABASE_H

#include <vector>
#include <string>
#include <cassert>
#include <tcutil.h>
#include <tchdb.h>
#include "maxlink_types.h"
#include "hdb_tokyo_cabinet_database.h"

class String2NumGeneDatabase : public HdbTokyoCabinetDatabase {
 public:
String2NumGeneDatabase() : next_gene_id_(0) {};
  ~String2NumGeneDatabase() {};
  // 
  // Stores the gene id string together with the next available index number.
  // The output parameter gene_id is set to this index number.

  void storeGene(const std::string &id_string, maxlink_types::GeneId *gene_id) {
    assert(init_run_);
    assert(hdb_);
    // is it correct to use id_string.c_str() and id_string.size() + 1?
    // What happens with multibyte charcters in utf-8?
    if (!tchdbput(hdb_, id_string.c_str(), id_string.size() + 1, &next_gene_id_, sizeof(next_gene_id_))) {
      int error_code = tchdbecode(hdb_);
      fprintf(stderr, "error in tchdbput: %s\n", tchdberrmsg(error_code));
      exit(EXIT_FAILURE);
    }
    *gene_id = next_gene_id_;
    ++next_gene_id_;
  }
  std::string endingFilename() {
    return std::string("String2NumGeneDatabase.hdb");
  };
  bool translateString2Num(const std::string &id_string, maxlink_types::GeneId *gene_id) {
    assert(init_run_);
    assert(hdb_);
    int value_size = 0;
    maxlink_types::GeneId *result_ptr = static_cast<maxlink_types::GeneId *>(tchdbget(hdb_,  id_string.c_str(), id_string.size() + 1, &value_size));
    if (result_ptr) {
      *gene_id = *result_ptr;
      free(result_ptr);
      return true;
    } else { 
      return false;
    }
  }
private:
  maxlink_types::GeneId next_gene_id_;
};

#endif
